@@ -200,8 +200,8 @@ class Dockit:
         stdout = subprocess.getoutput(f'grep path \'{cls._PROJECT_PATH}/.gitmodules\' | sed \'s/.*= //\'')
         return {f'{cls._PROJECT_PATH}/{submodule}' for submodule in stdout.split('\n')}
 
-    @staticmethod
-    def _pull_command(path):
+    @classmethod
+    def _pull_command(cls, path):
         repo = path.split('/')[-1]
         info = subprocess.getoutput(f'git -C {path} pull')
         if '已經是最新的' in info or 'Already up to date.' in info:
